@@ -2,12 +2,10 @@
 DEBUG = True
 TEMPLATE_DEBUG = DEBUG
 
-ADMINS = (
-    ('My Name', 'your_email@domain.com'),
-)
+ADMINS = ()
 MANAGERS = ADMINS
 
-import tempfile, os
+import tempfile, os, hashlib, datetime
 from django import contrib
 tempdata = tempfile.mkdtemp()
 approot = os.path.dirname(os.path.abspath(__file__))
@@ -32,6 +30,8 @@ MEDIA_URL = '/face/'
 STATIC_ROOT = os.path.join(tempdata, 'static', 'admin')[0]
 STATIC_URL = '/staticfiles/'
 ADMIN_MEDIA_PREFIX = '/admin-media/'
+SECRET_KEY = hashlib.sha1(
+    datetime.datetime.now().isoformat()).hexdigest()
 
 TEMPLATE_DIRS = (
     os.path.join(approot, 'templates'),
@@ -63,7 +63,6 @@ TEMPLATE_CONTEXT_PROCESSORS = (
     "django.contrib.auth.context_processors.auth",
     "django.core.context_processors.request",
     "django.core.context_processors.debug",
-    #"django.core.context_processors.i18n", this is AMERICA
     "django.core.context_processors.media",
 )
 
